[Sciviews-commits] r515 - in pkg: SciViews/R svDialogs/R svGUI svGUI/R svGUI/man svHttp/R svKomodo svKomodo/R svKomodo/inst svKomodo/man svMisc svMisc/R svMisc/man svSocket svSocket/R svSocket/man svUnit/R svWidgets/R svWidgets/man tcltk2/R tcltk2/man

noreply at r-forge.r-project.org noreply at r-forge.r-project.org
Sun Jan 27 18:39:15 CET 2013


Author: phgrosjean
Date: 2013-01-27 18:39:14 +0100 (Sun, 27 Jan 2013)
New Revision: 515

Modified:
   pkg/SciViews/R/SciViews-internal.R
   pkg/SciViews/R/misc.R
   pkg/svDialogs/R/menu.R
   pkg/svDialogs/R/svDialogs-internal.R
   pkg/svGUI/NEWS
   pkg/svGUI/R/guiAdd.R
   pkg/svGUI/R/svGUI-internal.R
   pkg/svGUI/man/guiAdd.Rd
   pkg/svHttp/R/httpServer.R
   pkg/svKomodo/NEWS
   pkg/svKomodo/R/svKomodo-internal.R
   pkg/svKomodo/inst/NEWS.Rd
   pkg/svKomodo/man/koInstall.Rd
   pkg/svMisc/DESCRIPTION
   pkg/svMisc/NEWS
   pkg/svMisc/R/TempEnv.R
   pkg/svMisc/R/batch.R
   pkg/svMisc/R/completion.R
   pkg/svMisc/R/guiCmd.R
   pkg/svMisc/R/objBrowse.R
   pkg/svMisc/R/objInfo.R
   pkg/svMisc/R/objList.R
   pkg/svMisc/R/objMenu.R
   pkg/svMisc/R/objSearch.R
   pkg/svMisc/R/pkgMan.R
   pkg/svMisc/R/progress.R
   pkg/svMisc/man/TempEnv.Rd
   pkg/svMisc/man/addItems.Rd
   pkg/svMisc/man/addTemp.Rd
   pkg/svMisc/man/assignTemp.Rd
   pkg/svMisc/man/changeTemp.Rd
   pkg/svMisc/man/existsTemp.Rd
   pkg/svMisc/man/getTemp.Rd
   pkg/svMisc/man/guiCmd.Rd
   pkg/svMisc/man/objBrowse.Rd
   pkg/svMisc/man/progress.Rd
   pkg/svMisc/man/rmTemp.Rd
   pkg/svMisc/man/svMisc-package.Rd
   pkg/svSocket/NEWS
   pkg/svSocket/R/parSocket.R
   pkg/svSocket/R/startSocketServer.R
   pkg/svSocket/R/stopSocketServer.R
   pkg/svSocket/man/parSocket.Rd
   pkg/svUnit/R/guiTestReport.R
   pkg/svUnit/R/svUnit-internal.R
   pkg/svWidgets/R/tkImg.R
   pkg/svWidgets/R/tkMenu.R
   pkg/svWidgets/R/tkTool.R
   pkg/svWidgets/R/tkWin.R
   pkg/svWidgets/man/Img.Rd
   pkg/svWidgets/man/Menu.Rd
   pkg/svWidgets/man/Tool.Rd
   pkg/svWidgets/man/Win.Rd
   pkg/tcltk2/R/tclTask.R
   pkg/tcltk2/R/tcltk2-Internal.R
   pkg/tcltk2/R/tk2fonts.R
   pkg/tcltk2/man/tk2fonts.Rd
Log:
In svMisv, TempEnv is renamed SciViews:TempEnv to avoid potential conflicts with other CRAN packages

Modified: pkg/SciViews/R/SciViews-internal.R
===================================================================
--- pkg/SciViews/R/SciViews-internal.R	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/SciViews/R/SciViews-internal.R	2013-01-27 17:39:14 UTC (rev 515)
@@ -56,12 +56,12 @@
 ## Code borrowed from svMisc, to avoid a dependency!
 .assignTemp <- function (x, value, replace.existing = TRUE) {
     .TempEnv <- function () {
-		pos <-  match("TempEnv", search())
+		pos <-  match("SciViews:TempEnv", search())
 		if (is.na(pos)) { # Must create it
-		    TempEnv <- list()
-		    attach(TempEnv, pos = length(search()) - 1)
-		    rm(TempEnv)
-		    pos <- match("TempEnv", search())
+		    `SciViews:TempEnv` <- list()
+		    attach(`SciViews:TempEnv`, pos = length(search()) - 1)
+		    rm(`SciViews:TempEnv`)
+		    pos <- match("SciViews:TempEnv", search())
 		}
 		pos.to.env(pos)
 	}

Modified: pkg/SciViews/R/misc.R
===================================================================
--- pkg/SciViews/R/misc.R	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/SciViews/R/misc.R	2013-01-27 17:39:14 UTC (rev 515)
@@ -468,8 +468,8 @@
 autoloadEnv <- function () return(.AutoloadEnv)
 #.AutoloadEnv already defined
 #TempEnv() in svMisc
-tempEnv <- svMisc::TempEnv
-.TempEnv <- svMisc::TempEnv()
+tempEnv <- .TempEnv()
+.TempEnv <- TempEnv()
 ## TODO: or sys.topEnv()???
 ## RCMD check claims he cannot find isNamespaceEnv() in topEnv() => provide it
 isNamespaceEnv <- function (envir = parentFrame())

Modified: pkg/svDialogs/R/menu.R
===================================================================
--- pkg/svDialogs/R/menu.R	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svDialogs/R/menu.R	2013-01-27 17:39:14 UTC (rev 515)
@@ -759,7 +759,7 @@
 ## This holds the custom menu structure in an R object
 .Rmenu <- function ()
 {
-	## The custom R menu is cached in a Rmenu object in TempEnv
+	## The custom R menu is cached in a Rmenu object in SciViews:TempEnv
 	return(.getTemp("Rmenu", default = list(), mode = "list"))
 }
 
@@ -891,7 +891,7 @@
 
 .unixMenuSave <- function (mnu, file = TRUE)
 {
-	## Save the menu structure in both Rmenu object in TempEnv and in a file
+	## Save the menu structure in Rmenu object in SciViews:TempEnv and in a file
 	## mnu is either a list of lists with menu entries, or NULL to delete all
 	## custom menus
 	.assignTemp("Rmenu", mnu)

Modified: pkg/svDialogs/R/svDialogs-internal.R
===================================================================
--- pkg/svDialogs/R/svDialogs-internal.R	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svDialogs/R/svDialogs-internal.R	2013-01-27 17:39:14 UTC (rev 515)
@@ -28,12 +28,12 @@
 ## Avoid dependency on svMisc for those two functions
 .TempEnv <- function ()
 {
-    pos <-  match("TempEnv", search())
+    pos <-  match("SciViews:TempEnv", search())
     if (is.na(pos)) { # Must create it
-        TempEnv <- list()
-        attach(TempEnv, pos = length(search()) - 1)
-        rm(TempEnv)
-        pos <- match("TempEnv", search())
+        `SciViews:TempEnv` <- list()
+        attach(`SciViews:TempEnv`, pos = length(search()) - 1)
+        rm(`SciViews:TempEnv`)
+        pos <- match("SciViews:TempEnv", search())
     }
     return(pos.to.env(pos))
 }

Modified: pkg/svGUI/NEWS
===================================================================
--- pkg/svGUI/NEWS	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svGUI/NEWS	2013-01-27 17:39:14 UTC (rev 515)
@@ -101,7 +101,7 @@
 
 * Correction of a bug in the first example of koCmd()
 
-* guiInstall() now creates a hook to koCmd(): .koCmd() in TempEnv environment
+* guiInstall() now creates a hook to koCmd(): .koCmd() in SciViews:TempEnv
 
 
 == Changes in svGUI 0.9-40

Modified: pkg/svGUI/R/guiAdd.R
===================================================================
--- pkg/svGUI/R/svGUI-internal.R	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svGUI/R/svGUI-internal.R	2013-01-27 17:39:14 UTC (rev 515)
@@ -15,12 +15,12 @@
 ## internally used)
 .TempEnv <- function ()
 {
-    pos <-  match("TempEnv", search())
+    pos <-  match("SciViews:TempEnv", search())
     if (is.na(pos)) { # Must create it
-        TempEnv <- list()
-        attach(TempEnv, pos = length(search()) - 1)
-        rm(TempEnv)
-        pos <- match("TempEnv", search())
+        `SciViews:TempEnv` <- list()
+        attach(`SciViews:TempEnv`, pos = length(search()) - 1)
+        rm(`SciViews:TempEnv`)
+        pos <- match("SciViews:TempEnv", search())
     }
     return(pos.to.env(pos))
 }

Modified: pkg/svGUI/man/guiAdd.Rd
===================================================================
--- pkg/svGUI/man/guiAdd.Rd	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svGUI/man/guiAdd.Rd	2013-01-27 17:39:14 UTC (rev 515)
@@ -28,7 +28,7 @@
 
 \arguments{
   \item{gui.name}{ the name of the GUI. It is also the name of the object stored
-    in TempEnv where you can access it. Although not required,
+    in SciViews:TempEnv where you can access it. Although not required,
     you are better to use short, syntactically correct names. }
   \item{widgets}{ the list of widgets that GUI uses, listed in a priority
     order. }
@@ -53,7 +53,7 @@
   \code{guiChange()}, \code{guiWidgets(agui) <- value} or
   \code{guiAsk(agui) <- value}. For \code{guiRemove()}, \code{TRUE} if an object
   was removed, or \code{FALSE} if the object was not there, invisibly. For
-  \code{guiList()}, the list of current 'gui' objects in TempEnv, or a
+  \code{guiList()}, the list of current 'gui' objects in SciViews:TempEnv, or a
   zero-length character if none (should not happen, since \code{.GUI}, the
   default GUI, cannot be removed).
 }
@@ -63,7 +63,7 @@
 \seealso{ \code{\link{gui}}, \code{\link{setUI}}, \code{\link{dontAsk}} }
 
 \examples{
-## A 'gui' object named .GUI is automatically created in TempEnv
+## A 'gui' object named .GUI is automatically created in SciViews:TempEnv
 guiList()
 
 ## Create a new GUI object to manage a separate GUI in the same R session

Modified: pkg/svHttp/R/httpServer.R
===================================================================
--- pkg/svHttp/R/httpServer.R	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svHttp/R/httpServer.R	2013-01-27 17:39:14 UTC (rev 515)
@@ -73,7 +73,7 @@
 		e$multiline <- TRUE  # Allow for multiline code
 		e$bare <- TRUE       # Always start in "bare" mode
 		## Note: in bare mode, all other parameters are inactive!
-		## and assign it to TempEnv
+		## and assign it to SciViews:TempEnv
 		assign(sc, e, envir = TempEnv())
 	} else e <- get(sc, envir = TempEnv(), mode = "environment")
 	

Modified: pkg/svKomodo/NEWS
===================================================================
--- pkg/svKomodo/NEWS	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svKomodo/NEWS	2013-01-27 17:39:14 UTC (rev 515)
@@ -7,8 +7,9 @@
 
 == Changes in svKomodo 0.9-57
 
-* svKomodo creates now at loading a .Last.sys() function in TempEnv indicating
-  to Komodo Edit that R has quit. This is required to update R menus there.
+* svKomodo creates now at loading a .Last.sys() function in SciViews:TempEnv
+  indicating to Komodo Edit that R has quit. This is required to update R menus
+  there.
   
 * The SciViews-K configuration file is not saved from here anymore (CRAN
   now does not accept packages that write files elsewhere than in R temp dir).
@@ -128,7 +129,7 @@
 
 * Correction of a bug in the first example of koCmd()
 
-* guiInstall() now creates a hook to koCmd(): .koCmd() in TempEnv environment
+* guiInstall() now creates a hook to koCmd(): .koCmd() in SciViews:TempEnv
 
 
 == Changes in svGUI 0.9-40

Modified: pkg/svKomodo/R/svKomodo-internal.R
===================================================================
--- pkg/svKomodo/R/svKomodo-internal.R	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svKomodo/R/svKomodo-internal.R	2013-01-27 17:39:14 UTC (rev 515)
@@ -334,14 +334,14 @@
 
 		## Create a .Last.sys function that clears some variables in .GlobalEnv
 		## and then, switch to R.initdir before closing R. The function is
-		## stored in TempEnv()
+		## stored in SciViews:TempEnv
 		assignTemp(".Last.sys", function () {
 			## Eliminate some known hidden variables from .GlobalEnv to prevent
 			## saving them in the .RData file
 			if (exists(".required", envir = .GlobalEnv, inherits = FALSE))
 				rm(list = ".required", envir = .GlobalEnv, inherits = FALSE)
-			## Note: .SciViewsReady is now recorded in TempEnv() instead of
-			## .GlobalEnv, but we leave this code for old workspaces...
+			## Note: .SciViewsReady is now recorded in SciViews:TempEnv instead
+			## of .GlobalEnv, but we leave this code for old workspaces...
 			if (exists(".SciViewsReady", envir = .GlobalEnv, inherits = FALSE))
 				rm(list = ".SciViewsReady", envir = .GlobalEnv, inherits = FALSE)
 			## If a R.initdir is defined, make sure to switch to it, so that

Modified: pkg/svKomodo/inst/NEWS.Rd
===================================================================
--- pkg/svKomodo/inst/NEWS.Rd	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svKomodo/inst/NEWS.Rd	2013-01-27 17:39:14 UTC (rev 515)
@@ -10,8 +10,8 @@
 \section{Changes in version 0.9-57}{
 	\itemize{
     \item{ svKomodo creates now at loading a \code{.Last.sys()} function in
-		 \code{TempEnv} indicating to Komodo Edit that R has quit. This is required
-		 to update R menus there. }
+		 \code{SciViews:TempEnv} indicating to Komodo Edit that R has quit. This
+		 is required to update R menus there. }
 	
 		\item{ The SciViews-K configuration file is not saved from here anymore
 			(CRAN now does not accept packages that write files elsewhere than in R

Modified: pkg/svKomodo/man/koInstall.Rd
===================================================================
--- pkg/svKomodo/man/koInstall.Rd	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svKomodo/man/koInstall.Rd	2013-01-27 17:39:14 UTC (rev 515)
@@ -4,8 +4,9 @@
 
 \title{ Install and uninstall hooks for communicating with Komodo Edit/IDE }
 \description{
-  Install functions in TempEnv and callbacks required to communicate with Komodo
-  Edit with the SciViews-K extension (see http://www.sciviews.org/SciViews-K).
+  Install functions in SciViews:TempEnv and callbacks required to communicate
+  with Komodo Edit with the SciViews-K extension
+  (see http://www.sciviews.org/SciViews-K).
 }
 \usage{
 koInstall()

Modified: pkg/svMisc/DESCRIPTION
===================================================================
--- pkg/svMisc/DESCRIPTION	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/DESCRIPTION	2013-01-27 17:39:14 UTC (rev 515)
@@ -1,7 +1,7 @@
 Package: svMisc
 Type: Package
-Version: 0.9-67
-Date: 2013-01-21
+Version: 0.9-68
+Date: 2013-01-27
 Title: SciViews GUI API - Miscellaneous functions
 Authors at R: c(person("Philippe", "Grosjean", role = c("aut", "cre"),
   email = "phgrosjean at sciviews.org"),
@@ -14,7 +14,7 @@
 Imports: utils, methods, tools
 Depends: R (>= 2.11.0)
 Suggests: svUnit, rJava
-Description: Supporting functions for the GUI API (various utilitary functions)
+Description: Supporting functions for the GUI API (various utility functions)
 License: GPL-2
 URL: http://www.sciviews.org/SciViews-R
 BugReports: https://r-forge.r-project.org/tracker/?group_id=194

Modified: pkg/svMisc/NEWS
===================================================================
--- pkg/svMisc/NEWS	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/NEWS	2013-01-27 17:39:14 UTC (rev 515)
@@ -1,5 +1,12 @@
 = svMisc News
 
+== Changes in svMisc 0.9-28
+
+* The temporary environment that TempEnv() attaches to the search path is now
+  called 'SciViews:TempEnv' instead of simply 'TempEnv' to avoid potential
+  conflicts with other packages in CRAN.
+
+
 == Changes in svMisc 0.9-67
 
 * Added the fileEdit() function.

Modified: pkg/svMisc/R/TempEnv.R
===================================================================
--- pkg/svMisc/R/TempEnv.R	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/R/TempEnv.R	2013-01-27 17:39:14 UTC (rev 515)
@@ -1,11 +1,11 @@
 TempEnv <- function ()
 {
-    pos <-  match("TempEnv", search())
+    pos <-  match("SciViews:TempEnv", search())
     if (is.na(pos)) { # Must create it
-        TempEnv <- list()
-        attach(TempEnv, pos = length(search()) - 1)
-        rm(TempEnv)
-        pos <- match("TempEnv", search())
+        `SciViews:TempEnv` <- list()
+        attach(`SciViews:TempEnv`, pos = length(search()) - 1)
+        rm(`SciViews:TempEnv`)
+        pos <- match("SciViews:TempEnv", search())
     }
     pos.to.env(pos)
 }

Modified: pkg/svMisc/R/batch.R
===================================================================
--- pkg/svMisc/R/batch.R	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/R/batch.R	2013-01-27 17:39:14 UTC (rev 515)
@@ -33,7 +33,7 @@
 	progress(n + 1, n) # Cancel progression message
 	if (verbose) message("Processed successfully ", sum(ok, na.rm = TRUE),
 		" items on ", n, " (see .last.batch)")
-	## Record .last.batch variable in TempEnv
+	## Record .last.batch variable in SciViews:TempEnv
 	lastBatch <- structure(sum(ok, na.rm = TRUE) == n, items = items, ok = ok)
 	assignTemp(".last.batch", lastBatch)
 	invisible(lastBatch)

Modified: pkg/svMisc/R/completion.R
===================================================================
--- pkg/svMisc/R/completion.R	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/R/completion.R	2013-01-27 17:39:14 UTC (rev 515)
@@ -118,8 +118,8 @@
 				} else packs <- .find.multiple(funs)
 				desc.fun <- rep("", length(packs))
 				## Do not try to find description for functions in those envs
-				isPack <- !packs %in% c("", ".GlobalEnv", "TempEnv", "Autoloads",
-					"tools:RGUI")
+				isPack <- !packs %in% c("", ".GlobalEnv", "SciViews:TempEnv",
+					"Autoloads", "tools:RGUI")
 				## The following code is too slow for many function
 				## (it takes 6-7sec for the 1210 base:::XXXX functions)
 				## So, do it only if less than max.fun

Modified: pkg/svMisc/R/guiCmd.R
===================================================================
--- pkg/svMisc/R/guiCmd.R	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/R/guiCmd.R	2013-01-27 17:39:14 UTC (rev 515)
@@ -1,7 +1,7 @@
 guiCmd <- function (command, ...)
 {
     ## This function sends a command to the GUI client
-    ## The actual code is a custom function named .guiCmd in TempEnv
+    ## The actual code is a custom function named .guiCmd in SciViews:TempEnv
 	CmdFun <- getTemp(".guiCmd", mode = "function")
     if (!is.null(CmdFun)) return(CmdFun(command, ...)) else return(NULL)
 }

Modified: pkg/svMisc/R/objBrowse.R
===================================================================
--- pkg/svMisc/R/objBrowse.R	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/R/objBrowse.R	2013-01-27 17:39:14 UTC (rev 515)
@@ -85,7 +85,7 @@
 		ParsChanged <- TRUE
 		Pars$group <- as.character(group[1])
 	}
-	## Write a cached version of these parameters in TempEnv
+	## Write a cached version of these parameters in SciViews:TempEnv
 	allPars <- getTemp(".guiObjParsCache", default = list())
 	allPars[[id]] <- Pars
 	assignTemp(".guiObjParsCache", allPars)

Modified: pkg/svMisc/R/objInfo.R
===================================================================
--- pkg/svMisc/R/objInfo.R	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/R/objInfo.R	2013-01-27 17:39:14 UTC (rev 515)
@@ -8,7 +8,7 @@
 	if (is.numeric(envir)) envir <- search()[envir[1]]
 	envir <- as.character(envir)[1]
 
-	## Possibly call a custom function .objInfo() in TempEnv
+	## Possibly call a custom function .objInfo() in SciViews:TempEnv
 	CmdFun <- getTemp(".objInfo", mode = "function")
     if (!is.null(CmdFun)) {  # We call a custom function
 		Info <- CmdFun(id = id, envir = envir, object = object)
@@ -16,7 +16,7 @@
 		Info <- switch(envir,
 			.GlobalEnv = paste(c("Global environment\n", capture.output(gc())),
 				collapse = "\n"),
-			TempEnv = "SciViews temporary variables environment",
+			`SciViews:TempEnv` = "SciViews temporary variables environment",
 			RcmdrEnv = "R Commander temporary variables environment",
 			`tools:RGUI` = "R.app tools environment",
 			Autoloads = "R autoloading objects environment",

Modified: pkg/svMisc/R/objList.R
===================================================================
--- pkg/svMisc/R/objList.R	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/R/objList.R	2013-01-27 17:39:14 UTC (rev 515)
@@ -127,7 +127,7 @@
 		allList <- getTemp(".guiObjListCache", default = list())
 
 		if (identical(res, allList[[id]])) Changed <- FALSE else {
-			## Keep a copy of the last version in TempEnv
+			## Keep a copy of the last version in SciViews:TempEnv
 			allList[[id]] <- res
 			assignTemp(".guiObjListCache", allList)
 		}

Modified: pkg/svMisc/R/objMenu.R
===================================================================
--- pkg/svMisc/R/objSearch.R	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/R/objSearch.R	2013-01-27 17:39:14 UTC (rev 515)
@@ -5,7 +5,7 @@
 		oldSearch <- getTemp(".guiObjSearchCache", default = "")
 		## Compare both versions
 		if (length(Search) != length(oldSearch) || !all(Search == oldSearch)) {
-			## Keep a copy of the last version in TempEnv
+			## Keep a copy of the last version in SciViews:TempEnv
 			assignTemp(".guiObjSearchCache", Search)
 			Changed <- TRUE
 		} else Changed <- FALSE

Modified: pkg/svMisc/R/pkgMan.R
===================================================================
--- pkg/svMisc/R/pkgMan.R	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/R/pkgMan.R	2013-01-27 17:39:14 UTC (rev 515)
@@ -29,7 +29,7 @@
 
 pkgManGetMirrors <- function ()
 {
-	## Cache the list of CRAN mirrors in TempEnv
+	## Cache the list of CRAN mirrors in SciViews:TempEnv
 	tmpVar <- "pkgMan.CRANmirrors"
 	if (existsTemp(tmpVar)) {
 		mirrors <- getTemp(tmpVar)

Modified: pkg/svMisc/R/progress.R
===================================================================
--- pkg/svMisc/R/progress.R	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/R/progress.R	2013-01-27 17:39:14 UTC (rev 515)
@@ -92,8 +92,8 @@
 	}
 
 	## An additional, graphical display of progression may be implemented too
-	## using custom functions as items in .progress in TempEnv... Here we look
-	## for and trigger them...
+	## using custom functions as items in .progress in SciViews:TempEnv...
+	## Here we look for and trigger them...
 	if (gui && length(CmdProgress) > 1) {
 		## Execute each item of the list that is a function
 		for (i in 1:length(CmdProgress))

Modified: pkg/svMisc/man/TempEnv.Rd
===================================================================
--- pkg/svMisc/man/TempEnv.Rd	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/man/TempEnv.Rd	2013-01-27 17:39:14 UTC (rev 515)
@@ -4,8 +4,8 @@
 \title{ Get an environment dedicated to temporary variables (and create it if
   needed) }
 \description{
-  This function creates and returns the reference to a TempEnv environment
-  located just before \code{Autoloads} on the search path.
+  This function creates and returns the reference to a SciViews:TempEnv
+  environment located just before \code{Autoloads} on the search path.
 }
 
 \usage{
@@ -13,7 +13,7 @@
 }
 
 \value{
-  TempEnv (an environment object)
+  SciViews:TempEnv (an environment object)
 }
 
 \author{ Philippe Grosjean <phgrosjean at sciviews.org> }

Modified: pkg/svMisc/man/addItems.Rd
===================================================================
--- pkg/svMisc/man/addItems.Rd	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/man/addItems.Rd	2013-01-27 17:39:14 UTC (rev 515)
@@ -25,7 +25,7 @@
   \item{use.names}{ use names of items to determine which one is unique,
     otherwise, the selection is done on the items themselves. }
   \item{replace}{ do we replace existing items in 'x'? }
-  \item{obj}{ the name of the object in \code{TempEnv()} to manipulate. }
+  \item{obj}{ the name of the object in \code{SciViews:TempEnv} to manipulate. }
   \item{text}{ the text of actions to add (label on first line, tip on other
     lines). }
   \item{code}{ the R code of actions to add. }

Modified: pkg/svMisc/man/addTemp.Rd
===================================================================
--- pkg/svMisc/man/addTemp.Rd	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/man/addTemp.Rd	2013-01-27 17:39:14 UTC (rev 515)
@@ -3,8 +3,9 @@
 
 \title{ Add data to an item in a temporary list variable }
 \description{
-  The function adds data to an item in a list variable located in TempEnv,
-  an environment dedicated to temporary variables (especially useful for GUIs).
+  The function adds data to an item in a list variable located in
+  SciViews:TempEnv, an environment dedicated to temporary variables (especially
+  useful for GUIs).
 }
 
 \usage{

Modified: pkg/svMisc/man/assignTemp.Rd
===================================================================
--- pkg/svMisc/man/assignTemp.Rd	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/man/assignTemp.Rd	2013-01-27 17:39:14 UTC (rev 515)
@@ -1,10 +1,10 @@
 \name{assignTemp}
 \alias{assignTemp}
 
-\title{ Assign a temporary variable in the TempEnv environment }
+\title{ Assign a temporary variable in the SciViews:TempEnv environment }
 \description{
-  The function assigns a variable to TempEnv, an environment dedicated to
-  temporary variables (especially useful for GUIs).
+  The function assigns a variable to SciViews:TempEnv, an environment dedicated
+  to temporary variables (especially useful for GUIs).
 }
 
 \usage{

Modified: pkg/svMisc/man/changeTemp.Rd
===================================================================
--- pkg/svMisc/man/changeTemp.Rd	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/man/changeTemp.Rd	2013-01-27 17:39:14 UTC (rev 515)
@@ -3,7 +3,7 @@
 
 \title{ Change an item in a temporary list variable }
 \description{
-  The function changes an item in a list variable located in TempEnv,
+  The function changes an item in a list variable located in SciViews:TempEnv,
   an environment dedicated to temporary variables (especially useful for GUIs).
 }
 

Modified: pkg/svMisc/man/existsTemp.Rd
===================================================================
--- pkg/svMisc/man/existsTemp.Rd	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/man/existsTemp.Rd	2013-01-27 17:39:14 UTC (rev 515)
@@ -1,9 +1,9 @@
 \name{existsTemp}
 \alias{existsTemp}
 
-\title{ Determine if a variable exists in TempEnv }
+\title{ Determine if a variable exists in SciViews:TempEnv }
 \description{
-  Does a variable exist in the TempEnv environment?
+  Does a variable exist in the SciViews:TempEnv environment?
 }
 \usage{
 existsTemp(x, mode = "any")
@@ -15,8 +15,8 @@
 }
 
 \value{
-  \code{TRUE} if the variable exists in TempEnv (and is of the correct mode),
-  \code{FALSE} otherwise.
+  \code{TRUE} if the variable exists in SciViews:TempEnv (and is of the correct
+  mode), \code{FALSE} otherwise.
 }
 
 \author{ Philippe Grosjean <phgrosjean at sciviews.org> }

Modified: pkg/svMisc/man/getTemp.Rd
===================================================================
--- pkg/svMisc/man/getTemp.Rd	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/man/getTemp.Rd	2013-01-27 17:39:14 UTC (rev 515)
@@ -1,10 +1,10 @@
 \name{getTemp}
 \alias{getTemp}
 
-\title{ Get a temporary variable from the TempEnv environment }
+\title{ Get a temporary variable from the SciViews:TempEnv environment }
 \description{
-  The function gets a variable, or an item in a list variable from TempEnv, an
-  environment dedicated to temporary variables.
+  The function gets a variable, or an item in a list variable from
+  SciViews:TempEnv, an environment dedicated to temporary variables.
 }
 \usage{
 getTemp(x, default = NULL, mode = "any", item = NULL)
@@ -26,7 +26,7 @@
 
 \value{
   The content of the variable, of the item, or the default value if the variable
-  or item is not found in TempEnv, or of the wrong mode.
+  or item is not found in SciViews:TempEnv, or of the wrong mode.
 }
 
 \author{ Philippe Grosjean <phgrosjean at sciviews.org> }

Modified: pkg/svMisc/man/guiCmd.Rd
===================================================================
--- pkg/svMisc/man/guiCmd.Rd	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/man/guiCmd.Rd	2013-01-27 17:39:14 UTC (rev 515)
@@ -32,16 +32,16 @@
 
 \value{
   The result of the command if it succeed, or \code{NULL} if the command cannot
-  be run (i.e., \code{.guiCmd()} is not defined in \code{TempEnv}).
+  be run (i.e., \code{.guiCmd()} is not defined in \code{SciViews:TempEnv}).
 }
 
 \details{
-  You must define a function \code{.guiCmd()} in the \code{TempEnv} environment
-  that will take first argument as the name of the command to execute (like
-  \code{source}, \code{save}, \code{import}, etc), and \dots with arguments to
-  the command to send. Depending on your GUI, you should have code that
-  delegates the GUI elements (ex: display a dialog asking for a .Rdata file to
-  source) and then, execute the command in R with the selected file as
+  You must define a function \code{.guiCmd()} in the \code{SciViews:TempEnv}
+  environment that will take first argument as the name of the command to
+  execute (like \code{source}, \code{save}, \code{import}, etc), and \dots with
+  arguments to the command to send. Depending on your GUI, you should have code
+  that delegates the GUI elements (ex: display a dialog asking for a .Rdata file
+  to source) and then, execute the command in R with the selected file as
   attribute.
 }
 

Modified: pkg/svMisc/man/objBrowse.Rd
===================================================================
--- pkg/svMisc/man/objBrowse.Rd	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/man/objBrowse.Rd	2013-01-27 17:39:14 UTC (rev 515)
@@ -117,8 +117,8 @@
 ## For environments
 (objInfo(envir = ".GlobalEnv"))
 (objMenu(envir = ".GlobalEnv"))
-(objInfo(envir = "TempEnv"))
-(objMenu(envir = "TempEnv"))
+(objInfo(envir = "SciViews:TempEnv"))
+(objMenu(envir = "SciViews:TempEnv"))
 (objInfo(envir = "package:datasets"))
 (objMenu(envir = "package:datasets"))
 ## For an environment that does not exist on the search path (return "")

Modified: pkg/svMisc/man/progress.Rd
===================================================================
--- pkg/svMisc/man/progress.Rd	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/man/progress.Rd	2013-01-27 17:39:14 UTC (rev 515)
@@ -42,10 +42,11 @@
   The function uses backspace (\\8) to erase characters at the console.
   
   With \code{gui = TRUE}, the function looks for all functions defined in the
-  '.progress' list located in 'TempEnv' environment. Each function is executed
-  in turn with following call: \code{theGUIfunction(value, max.value)}. You are
-  responsible to create \code{theGUIfunction()} and to add it as an element in
-  the .progress list in TempEnv. See also example (5) hereunder.
+  '.progress' list located in \code{SciViews:TempEnv} environment. Each function
+  is executed in turn with following call: \code{theGUIfunction(value, max.value)}.
+  You are responsible to create \code{theGUIfunction()} and to add it as an
+  element in the .progress list in \code{SciViews:TempEnv}. See also example (5)
+  hereunder.
   
   If your GUI display of the progression offers the possibility to stop
   calculation (for instance, using a 'Cancel' button), you are responsible to

Modified: pkg/svMisc/man/rmTemp.Rd
===================================================================
--- pkg/svMisc/man/rmTemp.Rd	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/man/rmTemp.Rd	2013-01-27 17:39:14 UTC (rev 515)
@@ -1,9 +1,9 @@
 \name{rmTemp}
 \alias{rmTemp}
 
-\title{ Remove one or several temporary variable(s) from the TempEnv environment }
+\title{ Remove one or several temporary variable(s) from the SciViews:TempEnv environment }
 \description{
-  The function removes one or more variable(s) from TempEnv.
+  The function removes one or more variable(s) from SciViews:TempEnv.
 }
 
 \usage{
@@ -12,7 +12,7 @@
 
 \arguments{
   \item{x}{ the name of the variable (character string), or a vector of
-    characters with the name of all variables to remove from TempEnv. }
+    characters with the name of all variables to remove from SciViews:TempEnv. }
 }
 
 \value{
@@ -21,7 +21,8 @@
 }
 
 \section{Warning}{
-  This command issues no error message if variable(s) do not exist in TempEnv!
+  This command issues no error message if variable(s) do not exist in
+  SciViews:TempEnv!
 }
 
 \author{ Philippe Grosjean <phgrosjean at sciviews.org> }

Modified: pkg/svMisc/man/svMisc-package.Rd
===================================================================
--- pkg/svMisc/man/svMisc-package.Rd	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/man/svMisc-package.Rd	2013-01-27 17:39:14 UTC (rev 515)
@@ -12,8 +12,8 @@
   \tabular{ll}{
     Package: \tab svMisc\cr
     Type: \tab Package\cr
-    Version: \tab 0.9-67\cr
-    Date: \tab 2012-07-07\cr
+    Version: \tab 0.9-68\cr
+    Date: \tab 2013-01-27\cr
     License: \tab GPL 2 or above, at your convenience\cr
   }
   % TODO: add description of main functions here. Also add examples

Modified: pkg/svSocket/NEWS
===================================================================
--- pkg/svSocket/NEWS	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svSocket/NEWS	2013-01-27 17:39:14 UTC (rev 515)
@@ -58,7 +58,7 @@
 == Changes in svSocket 0.9-49
 
 * Small change in startSocketServer(): the Tcl/Tk callback function now calls
-  a closure located in TempEnv (SocketServerProc).
+  a closure located in SciViews:TempEnv (SocketServerProc).
 
 
 == Changes in svSocket 0.9-48

Modified: pkg/svSocket/R/parSocket.R
===================================================================
--- pkg/svSocket/R/parSocket.R	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svSocket/R/parSocket.R	2013-01-27 17:39:14 UTC (rev 515)
@@ -18,7 +18,7 @@
         e$multiline <- TRUE  # Allow for multiline code
         e$bare <- TRUE       # Always start in "bare" mode
         ## Note: in bare mode, all other parameters are inactive!
-        ## Assign it to TempEnv
+        ## Assign it to SciViews:TempEnv
         assign(sc, e, envir = TempEnv())
     } else e <- get(sc, envir = TempEnv(), mode = "environment")
     ## Change or add parameters if they are provided

Modified: pkg/svSocket/R/startSocketServer.R
===================================================================
--- pkg/svSocket/R/startSocketServer.R	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svSocket/R/startSocketServer.R	2013-01-27 17:39:14 UTC (rev 515)
@@ -68,12 +68,12 @@
 			}
 			
 			"TempEnv_" <- function () {
-				pos <-  match("TempEnv", search())
+				pos <-  match("SciViews:TempEnv", search())
 				if (is.na(pos)) {  # Must create it
-					TempEnv <- list()
-					attach(TempEnv, pos = length(search()) - 1)
-					rm(TempEnv)
-					pos <- match("TempEnv", search())
+					`SciViews:TempEnv` <- list()
[TRUNCATED]

To get the complete diff run:
    svnlook diff /svnroot/sciviews -r 515


More information about the Sciviews-commits mailing list
--- pkg/svGUI/R/guiAdd.R	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svGUI/R/guiAdd.R	2013-01-27 17:39:14 UTC (rev 515)
@@ -8,11 +8,11 @@
 reset = FALSE, ask)
 {
 	gui.name <- as.character(gui.name)[1]
 	## Do the object already exists in TempEnv?
 	if (exists(gui.name, envir = .TempEnv(), inherits = FALSE)) {
 		guiObj <- get(gui.name, envir = .TempEnv(), inherits = FALSE)
 		if (!is.gui(guiObj))
-			stop("'gui.name' must be a character string naming a 'gui' object in TempEnv")
+			stop("'gui.name' must be a character string naming a 'gui' object in SciViews:TempEnv")
 		guiWidgets(guiObj, reset = reset) <- widgets
 		if (isTRUE(reset)) {
 			## Make sure name is correct
@@ -20,7 +20,7 @@
 			## Use default for ask, if not provided
 			if (missing(ask)) guiObj$ask <- NULL
 		}
-	} else { # Create a new 'gui' object in TempEnv
+	} else { # Create a new 'gui' object in SciViews:TempEnv
 		if (is.na(gui.name))
 			stop("Wrong 'gui.name', provide a length 1 character string")
 		guiObj <- new.env(parent = .GlobalEnv)
@@ -54,7 +54,7 @@
 	return(invisible(TRUE))	
 }
 
 ## List all GUI objects found in TempEnv
 guiList <- function ()
 {
 	lst <- ls(envir = .TempEnv(), all.names = TRUE)
@@ -112,7 +112,7 @@
 				stop("'gui' object '", gui.or.name, "' not found")
 			guiObj <- get(gui.or.name, envir = .TempEnv(), inherits = FALSE)
 			if (!is.gui(guiObj))
-				stop("'gui.or.name' must be a 'gui' object in TempEnv or its name")
+				stop("'gui.or.name' must be a 'gui' object in SciViews:TempEnv or its name")
 		}
 
 		## Query or set guiObj$ask
@@ -8,11 +8,11 @@
 {
 	gui.name <- as.character(gui.name)[1]
-	## Do the object already exists in TempEnv?
+	## Do the object already exists in SciViews:TempEnv?
 	if (exists(gui.name, envir = .TempEnv(), inherits = FALSE)) {
 		guiObj <- get(gui.name, envir = .TempEnv(), inherits = FALSE)
@@ -54,7 +54,7 @@
 }
 
-## List all GUI objects found in TempEnv
+## List all GUI objects found in SciViews:TempEnv
 guiList <- function ()
 {

Modified: pkg/svGUI/R/svGUI-internal.R
===================================================================
--- pkg/svMisc/R/objMenu.R	2013-01-24 20:04:06 UTC (rev 514)
+++ pkg/svMisc/R/objMenu.R	2013-01-27 17:39:14 UTC (rev 515)
@@ -87,7 +87,7 @@
 				objType <- "environment"
 				req <- getOption("required.environments")
 				if (is.null(req))  # Use list of known sensible environments
-					req <- c("TempEnv", "RcmdrEnv", "Autoloads", "tools:RGUI")
+					req <- c("SciViews:TempEnv", "RcmdrEnv", "Autoloads", "tools:RGUI")
 				detachable <- !(envir %in% req)
 				if (detachable) state <- "" else state <- " (d)"
 				objPar <- detachable
@@ -203,7 +203,8 @@
 		}
 	}  # Done (menu construction)
 
 	## Possibly call a custom function .objMenu() in TempEnv to finalize the menu
 	## Depending on objType, we send something we already calculated to avoid
 	## doing it twice:
 	## objType   -> objPar
@@ -203,7 +203,8 @@
 	}  # Done (menu construction)
 
-	## Possibly call a custom function .objMenu() in TempEnv to finalize the menu
+	## Possibly call a custom function .objMenu() in SciViews:TempEnv
+	## to finalize the menu
 	## Depending on objType, we send something we already calculated to avoid
 	## doing it twice:

Modified: pkg/svMisc/R/objSearch.R
===================================================================